@@ -1,8 +1,9 @@
 <?php 
+
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -20,10 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: index.php,v 1.3 2004/06/16 08:29:57 alec Exp $
+ *  $Id: index.php,v 1.4.2.3 2005/01/01 19:19:07 alec Exp $
  */
 
-include_once("class.php");
+include_once('class.php');
+$error = $_GET['error'];
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
 <html><head>
@@ -47,50 +49,27 @@ INPUT		{ font-size:  8pt; font-family: Tahoma, Verdana, Arial, Helvetica; border
 		<TR>
 			<TD>
    <P>
-                                        <IMG SRC="http://lms.rulez.pl/img/logo.png" BORDER="0" ALT="[ Witamy w LMS 1.3 ;-) ]">
+                                        <IMG SRC="http://lms.rulez.pl/img/logo.png" BORDER="0" ALT="[ Witamy w LMS 1.5 ]">
                                 </P>
                                 <P>
                                 <B>
-                                        &copy; 2002 Rulez Development Team - <a href="http://www.rulez.pl/" target="_blank">http://www.rulez.pl</A><BR>
+                                        &copy; 2001-2005 LMS Developers - <a href="http://lms.rulez.pl/" target="_blank">http://lms.rulez.pl</A><BR>
                                         &copy; 2001-2003 ASK NetX - <a href="http://www.netx.waw.pl/" target="_blank">http://www.netx.waw.pl</A><BR>
 				</B>
 				</P>
 				<P><DIV ALIGN="CENTER"><CENTER>
-<H2>
-W celu sprawdzenia stanu konta, prosimy wypeni poniszy formularz podajc numer umowy oraz PIN, ktry przesany zosta na Pastwa skrzynk e-mail.
-<!--						{if $error}<FONT COLOR="red"><B>{$error}</B></FONT><BR>{/if} -->
-							<TABLE>
-						<FORM METHOD="POST" NAME="loginform" ACTION="balanceview.php">
-								<TR>
-									<TD align="right">
-										<B>Nr Umowy:&nbsp;</B>
-									</TD>
-									<TD>
-										<INPUT TYPE="TEXT" NAME="loginform[login]" SIZE="20" ACCESSKEY="l"><BR>
-									</TD>
-								</TR>
-								<TR>
-									<TD align="right">
-										<B>PIN:&nbsp;</B>
-									</TD>
-									<TD>
-										<INPUT TYPE="PASSWORD" NAME="loginform[pwd]" SIZE="20"><BR>
-									</TD>
-								</TR>
-								<TR>
-									<TD COLSPAN="2">
-										&nbsp;
-									</TD>
-								</TR>
-                                                                        <TD COLSPAN="2" align="CENTER">
-                                                                                <INPUT TYPE="SUBMIT" NAME="loginform[submit]" VALUE="Moje Konto -- Logowanie">
-                                                                        </TD>
-								</TR>
-
-
-
-							</TABLE>
-
+		    <H2>W celu sprawdzenia stanu konta, prosimy wypeni poniszy formularz podajc numer umowy oraz PIN, ktry przesany zosta na Pastwa skrzynk e-mail.</H2>
+<?php 
+if($error)
+echo '<FONT COLOR="red"><B>Wprowadzono bdne dane!</B></FONT><BR>';
+?>
+						<P><FORM METHOD="POST" NAME="loginform" ACTION="balanceview.php">
+							<B>Nr Umowy:</B><BR>
+							<INPUT TYPE="TEXT" NAME="loginform[login]" SIZE="20" ACCESSKEY="l"><BR>
+							<B>PIN:</B><BR>
+							<INPUT TYPE="PASSWORD" NAME="loginform[pwd]" SIZE="20"><BR><BR>
+                                                        <INPUT TYPE="SUBMIT" NAME="loginform[submit]" VALUE="Logowanie">
+						</FORM></P>
 				</CENTER></DIV></P>
 				<P>
 					<BR>
