@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: sql.php,v 1.6 2004/04/12 19:24:25 alec Exp $
+ *  $Id: sql.php,v 1.7.2.2 2005/01/01 19:19:07 alec Exp $
  */
  
 $layout['pagetitle'] = 'SQL';
@@ -84,7 +84,7 @@ if($query = $_POST['query'])
 				$result .= '<TR CLASS="LIGHT"><TD CLASS="BLEND">'.$i.'</TD>';
 				foreach($colnames as $column)	
 				{
-					$result .= '<TD>'.$row[$column].'</TD>';
+					$result .= '<TD>'.nl2br(htmlspecialchars($row[$column])).'</TD>';
 				}
 				$result .= '</TR>';
 			}
