@@ -1,9 +1,9 @@
  /******************************************************************
  *	              A.L.E.C's LMS Daemon
  *******************************************************************
- *  LMS version 1.3.6 Osiris
+ *  LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- * $Id: almsd.c,v 1.18 2004/08/30 19:00:05 alec Exp $ 
+ * $Id: almsd.c,v 1.24.2.2 2005/01/01 19:19:08 alec Exp $ 
  */
 
 #include <unistd.h>
@@ -43,14 +43,15 @@ int main(int argc, char *argv[])
     int sleeptime = 0;			//
     int quit = 0;			//
     unsigned char *ini_file="/etc/lms/lms.ini";
-    unsigned char *db, *user, *passwd, *host; //db connection params
-    int port;				//
-    dictionary *ini;			//config
-    int reload, reload_t = 0;    
-    unsigned char *instance, *instances;
+    unsigned char *db, *user, *passwd, *host; 	//db connection params
+    int port;					//
+    dictionary *ini;				//config
+    int reload = 0, counter = 0, reload_t = 0;	    
+    unsigned char *instance, *instances, *iopt=NULL;
+    unsigned char *command;
 
     	// read command line args
-    	while ( (opt = getopt(argc, argv, "hc:bs:q")) != -1 ) {
+    	while ( (opt = getopt(argc, argv, "hc:bs:qi:")) != -1 ) {
 		switch (opt) {
         	case 'b':
                 	background = 1;
@@ -64,17 +65,21 @@ int main(int argc, char *argv[])
 		case 'q':
         		quit = 1;
                 	break;
+		case 'i':
+        		iopt = strdup(optarg);
+                	break;
 		case 'h':
         	default:
-			printf("A.L.E.C's LMS Daemon v.1.0. Command line options:\n");
+			printf("A.L.E.C's LMS Daemon v.1.4.5 Persus. Command line options:\n");
 			printf(" -c \tpath to config file (default: /etc/lms/lms.ini)\n");
-                	printf(" -b \tfork in background\n");
+                	printf(" -i \tlist of instances to reload\n");
+			printf(" -b \tfork in background\n");
                 	printf(" -s \tthe time the run sleeps for (seconds)\n");
                 	printf(" -q \tdo a reload and quit\n");
                 	exit(1);
 		}
     	}
-    
+
     	// start logging 
 #ifdef DEBUG1
     	syslog(LOG_INFO, "A.L.E.C's LMS Daemon started.");
@@ -112,7 +117,7 @@ int main(int argc, char *argv[])
     	if ( background ) {
 		int fval = fork();
         	if ( fval < 0 ) {
-    	    		syslog(LOG_CRIT,"Fork error");;
+    	    		syslog(LOG_CRIT,"Fork error");
             		exit(1); /* fork error */
         	} else if ( fval > 0 ) {
 #ifdef DEBUG1
@@ -139,8 +144,9 @@ int main(int argc, char *argv[])
     	user = strdup(iniparser_getstring(ini,"database:user","lms"));
     	passwd = strdup(iniparser_getstring(ini,"database:password",""));
     	port = iniparser_getint(ini,"database:port",0);
-    
-    	// set sleeptime
+    	command = strdup(iniparser_getstring(ini,"lmsd:command",""));
+    	
+	// set sleeptime
     	if( !sleeptime )
 		sleeptime = iniparser_getint(ini,"lmsd:sleeptime",30);
 
@@ -151,6 +157,16 @@ int main(int argc, char *argv[])
     	for (;;) {
 		int time;
 		reload = 0;
+		
+		// don't reload while daemon starting in background mode
+		if( !quit && !counter ) {
+			counter++;
+			sleep(sleeptime);
+			continue;
+		}
+		
+		// run shell command, i.e. secure connections tuneling
+		system(command);
 	
 		// try to connect to database
 		if( !db_connect(db,user,passwd,host,port) ) {
@@ -162,7 +178,7 @@ int main(int argc, char *argv[])
         	// need reload?
         	if( quit )
    	    		reload = 1;
-		else {
+		else 
 	    		if( (res =  db_query("SELECT time FROM timestamps WHERE tablename = '_force'"))!=NULL ) {
 				time = atoi(db_get_data(res,0,"time"));
 				if( time>0 && time!=reload_t ) {
@@ -171,26 +187,27 @@ int main(int argc, char *argv[])
 				}
 				db_free(res);
 	    		}
-		}
 
 		if( reload ) { // **********************************************
 #ifdef DEBUG1
 	    		syslog(LOG_INFO, "Reload signal detected, calling modules...");
 #endif
-	    
-	    		// read configuration from lms.ini
-	    		ini = iniparser_load(ini_file);
-    
-	    		if( ini==NULL ) {
+			// read configuration from lms.ini
+    			ini = iniparser_load(ini_file);
+
+    			if( ini==NULL ) {
 				syslog(LOG_ERR, "Unable to load configuration file '%s'", ini_file);
 				if( quit ) termination_handler(0);
 				sleep(sleeptime);
 				continue;
-	    		}
-
-	    		// get instances list for reload
-	    		instances = strdup(iniparser_getstring(ini, "lmsd:instances",""));
-	    	
+    			}
+			
+			// get instances list for reload
+			if(iopt)
+				instances = strdup(iopt);
+	    		else 	
+				instances = strdup(iniparser_getstring(ini, "lmsd:instances",""));
+			
 			// let's initialize and reload instances/modules...
 	    		for( instance=strtok(instances," "); instance!=NULL; instance=strtok(NULL, " ") ) {	
     
@@ -249,6 +266,7 @@ int main(int argc, char *argv[])
 		db_disconnect();	  
 		if (quit) termination_handler(0);
 		sleep(sleeptime);    
+		counter++;
     	} // end of main loop **********************************************
 	return 0;
 }
