@@ -3,21 +3,80 @@
 *      DB.C - Database routines
 *
 ***************************************************************/
-/* $Id: db.c,v 1.12 2003/12/05 15:54:26 alec Exp $ */
+/* $Id: db.c,v 1.17.2.1 2004/09/28 08:58:07 alec Exp $ */
 
 #include <string.h>
 #include <syslog.h>
 #include <stdarg.h>
+#include <unistd.h>
+#include <math.h>
+#include <locale.h>
 #include "db.h"
 #include "util.h"
 
 #ifdef USE_MYSQL
 CONN_HANDLE conn;
+RESULT_HANDLE *res=NULL;
 #endif
 #ifdef USE_PGSQL
 CONN_HANDLE *conn=NULL;
-#endif
 RESULT_HANDLE *res=NULL;
+#endif
+#ifdef USE_SQLITE
+CONN_HANDLE *conn=NULL;
+RESULT_HANDLE res=0;
+/*************************** SQLite UDF functions *************************/
+// this would be in other file, maybe later ...
+static void inet_ntoa_f(sqlite_func *context, int argc, const char **argv)
+{
+    static char s[16];
+    unsigned long z = strtoll(argv[0], (char **)NULL, 10);
+    sprintf(s, "%ld.%ld.%ld.%ld", (z>>24)&0xff, (z>>16)&0xff, (z>>8)&0xff, z&0xff);
+    sqlite_set_result_string(context, s, -1);
+}
+
+static void inet_aton_f(sqlite_func *context, int argc, const char **argv)
+{
+    static char s1[4], s2[4], s3[4], s4[4], s[12];
+    unsigned long z;
+    sscanf(argv[0], "%[0-9].%[0-9].%[0-9].%[0-9]", s1, s2, s3, s4);
+    z = atoi(s1)*256*256*256+atoi(s2)*256*256+atoi(s3)*256+atoi(s4);
+    sprintf(s, "%u", z);
+    sqlite_set_result_string(context, s, -1);
+}
+
+static void floor_f(sqlite_func *context, int argc, const char **argv)
+{
+    static char s[12];
+    double z = strtod(argv[0], (char **)NULL);
+    sprintf(s,"%.0f", z);
+    sqlite_set_result_string(context, s, -1);
+}
+
+static void upper_f(sqlite_func *context, int argc, const char **argv) 
+{
+    unsigned char *z;
+    int i;
+    if( argc<1 || argv[0]==0 ) return;
+    z = sqlite_set_result_string(context, argv[0], -1);
+    if( z==0 ) return;
+    setlocale(LC_ALL, "");
+    for(i=0; z[i]; i++)
+        z[i] = toupper(z[i]);
+}
+
+static void lower_f(sqlite_func *context, int argc, const char **argv)
+{
+    unsigned char *z;
+    int i;
+    if( argc<1 || argv[0]==0 ) return;
+    z = sqlite_set_result_string(context, argv[0], -1);
+    if( z==0 ) return;
+    setlocale(LC_ALL, "");
+    for(i=0; z[i]; i++)
+        z[i] = tolower(z[i]);
+}
+#endif
 
 /************************* CONNECTION FUNCTIONS *************************/
 
@@ -43,13 +102,33 @@ int db_connect(const unsigned char *db, const unsigned char *user, const unsigne
     snprintf(connect_string,sizeof(connect_string)-1,"host='%s' dbname='%s' user='%s' port='%d' password='%s'",host,db,user,port,password);
     connect_string[sizeof(connect_string)-1]='\x0';
     conn = PQconnectdb(connect_string);
-    if(PQstatus(conn) == CONNECTION_BAD) {
+    if( PQstatus(conn) == CONNECTION_BAD ) {
 	syslog(LOG_CRIT,"[db_connect] Unable to connect to database. Error: %s",PQerrorMessage(conn));
 	PQfinish(conn);
         return ERROR;
     }
 #endif
-#ifdef DEBUG1
+#ifdef USE_SQLITE
+    char *error = NULL;
+    /* first check file, because if file isn't exist sqlite_open() creates file */
+    if( access(db, F_OK)!=0 ) {
+	syslog(LOG_CRIT,"[db_connect] Error: Database file not exist, check config!");
+	return ERROR;
+    }
+    conn = sqlite_open(db, 0, &error);
+    if( error ) {
+    	syslog(LOG_CRIT,"[db_connect] Unable to connect to database. Error: %s", error);
+	sqlite_freemem(error);
+        return ERROR;
+    }
+    /* add udf functions on every connect */	   
+    sqlite_create_function(conn, "inet_ntoa", 1, inet_ntoa_f, NULL);
+    sqlite_create_function(conn, "inet_aton", 1, inet_aton_f, NULL);
+    sqlite_create_function(conn, "floor", 1, floor_f, NULL);
+    sqlite_create_function(conn, "upper", 1, upper_f, NULL);
+    sqlite_create_function(conn, "lower", 1, lower_f, NULL);
+#endif
+#ifdef DEBUG0
 	syslog(LOG_INFO, "DEBUG: [lmsd] Connected with params: db='%s' host='%s' user='%s' port='%d' passwd='*'",db, host, user, port);
 #endif
     return OK;
@@ -59,16 +138,19 @@ int db_connect(const unsigned char *db, const unsigned char *user, const unsigne
 int db_disconnect(void)
 {
 #ifdef USE_MYSQL
-     mysql_close(&conn);
+    mysql_close(&conn);
 #endif
 #ifdef USE_PGSQL
-     if( PQstatus(conn) != CONNECTION_BAD )
-          PQfinish(conn);
+    if( PQstatus(conn) != CONNECTION_BAD )
+	PQfinish(conn);
 #endif
-#ifdef DEBUG1
+#ifdef USE_SQLITE
+    sqlite_close(conn);
+#endif
+#ifdef DEBUG0
     syslog(LOG_INFO, "DEBUG: [lmsd] Disconnected");
 #endif
-     return OK;
+    return OK;
 }
 
 /************************* QUERY FUNCTIONS ************************/
@@ -77,21 +159,40 @@ QUERY_HANDLE * db_query(unsigned char *q)
 {
     QUERY_HANDLE *query;
     unsigned char *stmt = strdup(q);
+#ifdef USE_SQLITE
+    COLUMN *my_col, *col;
+    ROW *my_row;
+    VALUE *val;
+    char *error = NULL;
+    const char *query_tail = NULL;
+    sqlite_vm *vm = NULL;
+    const char **results = NULL;
+    const char **columnNames = NULL;
+    int i, numCols = 0;
+    unsigned char *buf;
+#endif
     parse_query_stmt(&stmt);
 #ifdef DEBUG0
     syslog(LOG_INFO,"DEBUG: [SQL] %s", stmt);
 #endif
 #ifdef USE_MYSQL
-    if( mysql_query(&conn,stmt) < 0 ) {
+    if( mysql_query(&conn,stmt) != 0 ) {
 	syslog(LOG_CRIT,"[db_query] Query failed. Error: %s",mysql_error(&conn));
 	free(stmt);
 	return NULL;
     }
-    if ( (res = mysql_store_result(&conn)) == NULL ) {
+    if( (res = mysql_store_result(&conn)) == NULL ) {
 	syslog(LOG_CRIT,"[db_query] Unable to get query result. Error: %s",mysql_error(&conn));
 	free(stmt);
 	return NULL;
     }
+    if( mysql_num_rows(res) == 0 ) {  // empty result
+	free(stmt);
+	mysql_free_result(res);
+	return NULL;
+    }
+    query = get_query_result(res);
+    mysql_free_result(res);
 #endif
 #ifdef USE_PGSQL
     res = PQexec(conn,stmt);
@@ -101,13 +202,47 @@ QUERY_HANDLE * db_query(unsigned char *q)
         free(stmt);
 	return NULL;
     }
-#endif
     query = get_query_result(res);
-#ifdef USE_MYSQL
-    mysql_free_result(res);
-#endif
-#ifdef USE_PGSQL
     PQclear(res);
+#endif
+#ifdef USE_SQLITE
+    sqlite_compile(conn, stmt, &query_tail, &vm, &error);
+    if( error ) {
+    	syslog(LOG_CRIT,"[db_query] Query failed. %s", error);
+	sqlite_freemem(error);
+        free(stmt);
+	return NULL;
+    }
+    query = (QUERY_HANDLE *) malloc(sizeof(QUERY_HANDLE));
+    my_row = (ROW *) malloc(sizeof(ROW));
+    query->nrows = 0;
+    
+    while( sqlite_step(vm, &numCols, &results, &columnNames)==SQLITE_ROW ) {
+	
+	    my_row = (ROW *) realloc(my_row, sizeof(ROW) * (query->nrows+1)); 
+    	    my_row[query->nrows].value = (VALUE *) calloc(numCols, sizeof(VALUE));
+            
+	    for( i=0; i<numCols; i++ ) {
+	   
+    		    val = &(my_row[query->nrows].value[i]);
+		    buf = (unsigned char *) (results[i] ? results[i] : "");
+		    val->data = str_save(val->data,buf);
+	    }
+	    query->nrows++; 
+    }
+    query->row = my_row;
+    query->ncols = numCols; 
+    my_col = (COLUMN *) malloc(query->ncols * sizeof(COLUMN));
+    for( i=0; i<numCols; i++ ) {
+  	    
+	    my_col[i].name = (char *) malloc(sizeof(char *));
+    	    col = &(my_col[i]);
+	    col->name = str_save(col->name, columnNames[i]);
+	    col->size = DB_UNKNOWN;
+	    col->type = DB_UNKNOWN;
+    }
+    query->col = my_col;
+    sqlite_finalize(vm, NULL);
 #endif
     free(stmt);
     return query;
@@ -153,8 +288,11 @@ QUERY_HANDLE * db_pquery(unsigned char *q, ... )
 /* executes a INSERT, UPDATE, DELETE queries */
 int db_exec(unsigned char *q)
 {
-    int result;
+    int result = 0;
     unsigned char *stmt = strdup(q);
+#ifdef USE_SQLITE
+    char *error = NULL;
+#endif
     parse_query_stmt(&stmt);
 #ifdef DEBUG0
     syslog(LOG_INFO,"DEBUG: [SQL] %s", stmt);
@@ -177,6 +315,16 @@ int db_exec(unsigned char *q)
     }
     result = atoi(PQcmdTuples(res));
     PQclear(res);
+#endif
+#ifdef USE_SQLITE
+    res = sqlite_exec(conn, stmt, NULL, NULL, &error);
+    if( error ) {
+    	syslog(LOG_CRIT,"[db_exec] Query failed. %s",error);
+	sqlite_freemem(error);
+	free(stmt);
+        return ERROR;
+    }
+    result = sqlite_changes(conn);
 #endif
     free(stmt);
     return result;
@@ -221,7 +369,7 @@ int db_pexec(unsigned char *q, ... )
 /* Internal function for SELECT query result fetching */
 static QUERY_HANDLE * get_query_result(RESULT_HANDLE * result)
 {
-    QUERY_HANDLE * query;
+    QUERY_HANDLE *query;
     COLUMN *my_col, *col;
     ROW *my_row;
     VALUE *val;
@@ -375,6 +523,9 @@ void parse_query_stmt(unsigned char **stmt)
 #ifdef USE_MYSQL
     str_replace(stmt,"%NOW%","UNIX_TIMESTAMP()");
 #endif
+#ifdef USE_SQLITE
+    str_replace(stmt,"%NOW%","strftime('%s','now')");
+#endif
 #ifdef USE_PGSQL
     str_replace(stmt,"%NOW%","EXTRACT(EPOCH FROM CURRENT_TIMESTAMP(0))");
     str_replace(stmt,"LIKE","ILIKE");
@@ -396,6 +547,18 @@ int db_begin()
         return ERROR;
     }
     PQclear(res);
+#endif
+#ifdef USE_SQLITE
+    char *error = NULL;
+    res = sqlite_exec(conn,"BEGIN", NULL, NULL, &error);
+#ifdef DEBUG0
+    syslog(LOG_INFO,"DEBUG: [SQL] BEGIN");
+#endif
+    if(res!=SQLITE_OK) {
+    	syslog(LOG_CRIT,"[db_begin] Query failed. Error: %s",error);
+	sqlite_freemem(error);
+        return ERROR;
+    }
 #endif
     return OK;
 }
@@ -414,6 +577,18 @@ int db_commit()
         return ERROR;
     }
     PQclear(res);
+#endif
+#ifdef USE_SQLITE
+    char *error = NULL;
+    res = sqlite_exec(conn,"COMMIT", NULL, NULL, &error);
+#ifdef DEBUG0
+    syslog(LOG_INFO,"DEBUG: [SQL] COMMIT");
+#endif
+    if(res!=SQLITE_OK) {
+    	syslog(LOG_CRIT,"[db_commit] Query failed. Error: %s",error);
+	sqlite_freemem(error);
+        return ERROR;
+    }
 #endif
     return OK;
 }
@@ -432,6 +607,18 @@ int db_abort()
         return ERROR;
     }
     PQclear(res);
+#endif
+#ifdef USE_SQLITE
+    char *error = NULL;
+    res = sqlite_exec(conn,"ROLLBACK", NULL, NULL, &error);
+#ifdef DEBUG0
+    syslog(LOG_INFO,"DEBUG: [SQL] ROLLBACK");
+#endif
+    if(res!=SQLITE_OK) {
+    	syslog(LOG_CRIT,"[db_abort] Query failed. Error: %s",error);
+	sqlite_freemem(error);
+        return ERROR;
+    }
 #endif
     return OK;
 }
@@ -470,7 +657,7 @@ unsigned char * db_get_data(QUERY_HANDLE *query, int row, const char *colname)
 	    break;
     }
     if( i>=query->ncols ) {
-	syslog(LOG_CRIT,"[db_get_str] Column '%s' not found",colname);
+	syslog(LOG_CRIT,"[db_get_data] Column '%s' not found",colname);
 	return "NULL";
     }
     
