@@ -1,7 +1,7 @@
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: oident.c,v 1.12 2004/03/22 09:23:12 alec Exp $
+ *  $Id: oident.c,v 1.13.2.2 2005/01/01 19:19:09 alec Exp $
  */
 
 #include <stdio.h>
@@ -44,7 +44,7 @@ void reload(GLOBAL *g, struct oident_module *o)
 
 	while( n>1 ) {
 		
-		n = sscanf(netnames, "%s %[a-zA-Z0-9- ]", netname, netnames);
+		n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
 
 		if( strlen(netname) ) {
 
