@@ -1,7 +1,7 @@
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tc.c,v 1.18 2004/07/26 11:03:44 alec Exp $
+ *  $Id: tc.c,v 1.19.2.3 2005/01/01 19:19:12 alec Exp $
  */
 
 #include <stdio.h>
@@ -55,7 +55,7 @@ void reload(GLOBAL *g, struct tc_module *tc)
 	// get table of networks
 	while( n>1 ) 
 	{
-		n = sscanf(netnames, "%s %[a-zA-Z0-9- ]", netname, netnames);
+		n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
 
 		if( strlen(netname) ) 
 			if( res = g->db_pquery("SELECT name, domain, address, INET_ATON(mask) AS mask, interface FROM networks WHERE UPPER(name)=UPPER('?')",netname)) 
@@ -78,7 +78,7 @@ void reload(GLOBAL *g, struct tc_module *tc)
 	// get table of usergroups
 	while( k>1 ) 
 	{
-		k = sscanf(groupnames, "%s %[a-zA-Z0-9- ]", groupname, groupnames);
+		k = sscanf(groupnames, "%s %[._a-zA-Z0-9- ]", groupname, groupnames);
 
 		if( strlen(groupname) )
 			if( res = g->db_pquery("SELECT name, id FROM usergroups WHERE UPPER(name)=UPPER('?')",groupname)) 
@@ -89,7 +89,6 @@ void reload(GLOBAL *g, struct tc_module *tc)
 					ugps[gc].name = strdup(g->db_get_data(res,0,"name"));
 					ugps[gc].id = atoi(g->db_get_data(res,0,"id"));
 					gc++;
-					printf("&");
 				}
     				g->db_free(res);
 			}				
