@@ -1,7 +1,7 @@
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: traffic.c,v 1.4 2004/02/18 12:49:22 lukasz Exp $
+ *  $Id: traffic.c,v 1.4.2.3 2005/04/24 06:42:59 alec Exp $
  */
 #include <stdio.h>
 #include <syslog.h>
@@ -79,7 +79,7 @@ void reload(GLOBAL *g, struct traffic_module *traffic)
 			// read file line by line
 			while( fgets(buffer, 100, fh)!=NULL ) {
 
-				if ( sscanf(buffer, "%[^\t ] %[^\t ] %s", host, download, upload) !=3 )
+				if ( sscanf(buffer, "%[^\t ] %[^\t ] %s", host, upload, download) !=3 )
 					continue; //if invalid data format
 					 
 				if( k = is_host(hosts, j, host) ) { // host exists ?
