@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Session.class.php,v 1.50 2004/07/12 19:17:36 alec Exp $
+ *  $Id: Session.class.php,v 1.51.2.3 2005/01/01 19:19:21 alec Exp $
  */
 
 class Session {
@@ -34,8 +34,8 @@ class Session {
 	var $last;
 	var $lastip;
 	var $error;
-	var $_version = '1.3-cvs';
-	var $_revision = '$Revision: 1.50 $';
+	var $_version = '1.4.5 Persus';
+	var $_revision = '$Revision: 1.51.2.3 $';
 
 	function Session(&$DB,$timeout = 600)
 	{
@@ -50,7 +50,7 @@ class Session {
 			$this->login = $loginform['login'];
 			$this->passwd = $loginform['pwd'];
 			$_SESSION['session_timestamp'] = time();
-			writesyslog("Login attempt by ".$this->login,LOG_INFO);
+			writesyslog('Login attempt by '.$this->login, LOG_INFO);
 		}
 		elseif($this->DB->GetOne('SELECT COUNT(id) FROM admins') == 0)
 		{
@@ -68,19 +68,19 @@ class Session {
 		
 		if($this->VerifyPassword()&&$this->TimeOut($timeout)){
 			$this->islogged = TRUE;
-			$admindata = $this->DB->GetRow("SELECT id, name FROM admins WHERE login=?",array($this->login));
+			$admindata = $this->DB->GetRow('SELECT id, name FROM admins WHERE login=?',array($this->login));
 			$this->id = $admindata['id'];
 			$this->logname = $admindata['name'];
 			$this->last = $_SESSION['session_last'];
 			$this->lastip = $_SESSION['session_lastip'];
 			if(isset($loginform))
 			{
-				$admindata = $this->DB->GetRow("SELECT lastlogindate, lastloginip FROM admins WHERE id=?",array($this->id));
+				$admindata = $this->DB->GetRow('SELECT lastlogindate, lastloginip FROM admins WHERE id=?',array($this->id));
 				$this->last = $admindata['lastlogindate'];
 				$this->lastip = $admindata['lastloginip'];
 				
-				$this->DB->Execute("UPDATE admins SET lastlogindate=?, lastloginip=? WHERE id=?",array(time(),$_SERVER['REMOTE_ADDR'],$this->id));
-				writesyslog("User ".$this->login." logged in",LOG_INFO);
+				$this->DB->Execute('UPDATE admins SET lastlogindate=?, lastloginip=? WHERE id=?', array(time(),$_SERVER['REMOTE_ADDR'],$this->id));
+				writesyslog('User '.$this->login.' logged in.', LOG_INFO);
 			}
 			$_SESSION['session_login'] = $this->login;
 			$_SESSION['session_passwd'] = $this->passwd;
@@ -90,8 +90,8 @@ class Session {
 			$this->islogged = FALSE;
 			if(isset($loginform))
 			{
-				writesyslog("Bad password for ".$this->login,LOG_WARNING);
-				$this->DB->Execute("UPDATE admins SET failedlogindate=?, failedloginip=? WHERE login=?",array(time(),$_SERVER['REMOTE_ADDR'],$this->login));
+				writesyslog('Bad password for '.$this->login, LOG_WARNING);
+				$this->DB->Execute('UPDATE admins SET failedlogindate=?, failedloginip=? WHERE login=?',array(time(),$_SERVER['REMOTE_ADDR'],$this->login));
 			}
 			$this->LogOut();
 		}
@@ -105,7 +105,7 @@ class Session {
 	function LogOut()
 	{
 		if ($this->islogged)
-			writesyslog("User ".$this->login." logged out.",LOG_INFO);
+			writesyslog('User '.$this->login.' logged out.',LOG_INFO);
 		session_destroy();
 		unset($this->login);
 		unset($this->password);
@@ -116,7 +116,7 @@ class Session {
 	{
 		if( (time() - $_SESSION['session_timestamp']) > $timeout )
 		{
-			$this->error = "Przekroczye limit czasu bezczynnoci (".$timeout." sekund).";
+			$this->error = 'Przekroczye limit czasu bezczynnoci ('.$timeout.' sekund).';
 			return FALSE;
 		}
 		else
@@ -128,16 +128,15 @@ class Session {
 	
 	function VerifyPassword()
 	{
-		$dbpasswd = $this->DB->GetOne("SELECT passwd FROM admins WHERE login=?",array($this->login));
-		$dblogin = $this->DB->GetOne("SELECT login FROM admins WHERE login=?",array($this->login));
+		$dbpasswd = $this->DB->GetOne('SELECT passwd FROM admins WHERE login=? AND deleted=0',array($this->login));
 		if (crypt($this->passwd,$dbpasswd)==$dbpasswd)
 			return TRUE;
 		else 
 		{
 			if(isset($this->login))
-				$this->error="Bdne haso lub nazwa uytkownika.";
+				$this->error='Bdne haso lub nazwa uytkownika.';
 			else
-				$this->error="Prosz si zalogowa.";
+				$this->error='Prosz si zalogowa.';
 			return FALSE;
 		}
 	}
