@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Sysinfo.class.php,v 1.14 2004/07/28 06:32:35 alec Exp $
+ *  $Id: Sysinfo.class.php,v 1.15.2.3 2005/01/01 19:19:22 alec Exp $
  */
 
 /*
@@ -33,12 +33,12 @@ class Sysinfo {
 	
 	function get_sysinfo()
 	{
-		$return[hostname] = $this->hostname();
-		$return[uptime] = $this->uptime();
-		$return[kernel] = $this->kernel();
-		$return[users] = $this->users();
-		$return[loadavg] = $this->loadavg();
-		$return[phpversion] = phpversion();
+		$return['hostname'] = $this->hostname();
+		$return['uptime'] = $this->uptime();
+		$return['kernel'] = $this->kernel();
+		$return['users'] = $this->users();
+		$return['loadavg'] = $this->loadavg();
+		$return['phpversion'] = phpversion();
 		return $return;
 	}
 
@@ -223,7 +223,6 @@ class Sysinfo {
 		}
 		return $results;
 	}
-											    
 }
 
 ?>
