@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,21 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkdirs.php,v 1.20 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: checkdirs.php,v 1.21.2.2 2005/01/01 19:19:22 alec Exp $
  */
 
-
-
 if(!is_dir($_SMARTY_COMPILE_DIR))
-	die("Brakuje mi katalogu <B>".$_SMARTY_COMPILE_DIR."</B> - bd wdziczny jak kto go utworzy.");
+	die('Brakuje mi katalogu <B>'.$_SMARTY_COMPILE_DIR.'</B> - bd wdziczny jak kto go utworzy.');
 
 if(!is_writable($_SMARTY_COMPILE_DIR))
-	die("Nie mog zapisywa do katalogu <B>".$_SMARTY_COMPILE_DIR."</B> - mgby wykona komend:<BR><pre>chown ".posix_geteuid().".".posix_getegid()." ".$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR."</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.");
+	die('Nie mog zapisywa do katalogu <B>'.$_SMARTY_COMPILE_DIR.'</B> - mgby wykona komend:<BR><pre>chown '.posix_geteuid().'.'.posix_getegid().' '.$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR.'</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.');
 
 if(!is_dir($_BACKUP_DIR))
-	die("Brakuje mi katalogu <B>".$_BACKUP_DIR."</B> - bd wdziczny jak kto6 go utworzy.");
+	die('Brakuje mi katalogu <B>'.$_BACKUP_DIR.'</B> - bd wdziczny jak kto6 go utworzy.');
 	
 if(!is_writable($_BACKUP_DIR))
-	die("Nie mog zapisywa do katalogu <B>".$_BACKUP_DIR."</B> - mgby wykona komend:<BR><pre>chown ".posix_geteuid().".".posix_getegid()." ".$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR."</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.");
+	die('Nie mog zapisywa do katalogu <B>'.$_BACKUP_DIR.'</B> - mgby wykona komend:<BR><pre>chown '.posix_geteuid().'.'.posix_getegid().' '.$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR.'</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.');
 
 ?>
