@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: fortunes.php,v 1.8 2004/04/02 10:06:43 alec Exp $
+ *  $Id: fortunes.php,v 1.8.2.3 2005/01/01 19:19:24 alec Exp $
  */
 
 $fortunes[] = "Moesz si pokaleczy wymachujc siekier?";
@@ -114,6 +114,6 @@ $fortunes[] = "Prima Aprilis 2004 - lms@lists.rulez.pl:
 
 
 mt_srand ((double) microtime()* 100000000);
-$layout[fortune] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];
+$layout['fortune'] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];
 
 ?>
