@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: language.php,v 1.7 2004/03/08 20:19:03 lexx Exp $
+ *  $Id: language.php,v 1.8.2.2 2005/01/01 19:19:26 alec Exp $
  */
 
 // Plik do ustawiania locales i do translacji...
@@ -30,6 +30,8 @@
 // ustawienie komunikatw syst. na polskie
 setlocale(LC_MESSAGES,'pl_PL');
 // ustawienie formatu czasu na polski
-setlocale(LC_TIME,'pl_PL')
+setlocale(LC_TIME,'pl_PL');
+// kapitalizowanie literek
+setlocale(LC_CTYPE,'pl_PL');
 
 ?>
\ No newline at end of file
