@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminadd.php,v 1.28 2004/03/11 17:24:21 lukasz Exp $
+ *  $Id: adminadd.php,v 1.28.2.3 2005/02/26 17:35:03 alec Exp $
  */
 
 $adminadd = $_POST['adminadd'];
@@ -38,14 +38,19 @@ if(isset($adminadd))
 		die;
 	}
 	
-	if($LMS->GetAdminIDByLogin($adminadd['login']))
-		$error['login'] = "Podany login istnieje!";
+	if($adminadd['login']=="")
+		$error['login'] = "Login nie moe by pusty!";
 	elseif(!eregi("^[a-z0-9.-_]+$",$adminadd['login']))
 		$error['login'] = "Login zawiera niepoprawne znaki!";
+	elseif($LMS->GetAdminIDByLogin($adminadd['login']))
+		$error['login'] = "Konto z podanym loginem istnieje lub login ten by ju wykorzystany w przeszoci!";
 
 	if($adminadd['email']!="" && !check_email($adminadd['email']))
 		$error['email'] = "Podany email nie wydaje si by poprawny!";
 
+	if($adminadd['name']=="")
+		$error['name'] = "Pole 'imi i nazwisko' nie moe by puste!";
+
 	if($adminadd['password']=="")
 		$error['password'] = "Haso nie moe by puste!";
 	elseif($adminadd['password']!=$adminadd['confirm'])
