@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,16 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balanceadd.php,v 1.15 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: balanceadd.php,v 1.18.2.2 2005/01/01 19:19:46 alec Exp $
  */
 
 $addbalance = $_POST['addbalance'];
 
+$_SESSION['addtype'] = $addbalance['type'];
 $_SESSION['addbc'] = $addbalance['comment'];
 $_SESSION['addbt'] = $addbalance['time'];
 $_SESSION['addbv'] = $addbalance['value'];
+if ($addbalance['taxvalue'] == 'zw.')
+	$addbalance['taxvalue'] = '';
+$_SESSION['addbtax'] = $addbalance['taxvalue'];
 
 $addbalance['value'] = str_replace(",",".",$addbalance['value']);
+$addbalance['taxvalue'] = str_replace(",",".",$addbalance['taxvalue']);
 
 if($addbalance['time']) {
 
