@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,12 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.19 2004/04/08 15:21:59 chilek Exp $
+ *  $Id: balancenew.php,v 1.20.2.2 2005/01/01 19:19:47 alec Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
 $layout['pagetitle'] = "Nowa operacja finansowa";
+$SMARTY->assign('operation',$_SESSION['addtype']);
 $SMARTY->assign('comment',$_SESSION['addbc']);
 $SMARTY->assign('taxvalue', $_SESSION['addbtax']);
 $SMARTY->assign('time', $_SESSION['addbt']);
