@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chooseip.php,v 1.24 2004/03/11 17:24:21 lukasz Exp $
+ *  $Id: chooseip.php,v 1.25.2.2 2005/01/01 19:19:47 alec Exp $
  */
 
 $p = $_GET['p'];
@@ -35,10 +35,10 @@ $networks = $LMS->GetNetworks();
 
 if (isset($_POST['netid']))
     $netid= $_POST['netid'];
-
+elseif (isset($_GET['netid']))
+    $netid = $_GET['netid'];
 elseif (isset($_SESSION['netid']))
     $netid = $_SESSION['netid'];
-    
 else
     $netid = $networks[0]['id'];
 
@@ -53,6 +53,7 @@ $SMARTY->assign('part',$p);
 $SMARTY->assign('js',$js);
 $SMARTY->assign('networks',$networks);
 $SMARTY->assign('network',$network);
+$SMARTY->assign('netid',$netid);
 $SMARTY->display('chooseip.html');
 
 ?>
