@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbview.php,v 1.19 2004/03/11 17:24:21 lukasz Exp $
+ *  $Id: dbview.php,v 1.19.2.3 2005/01/01 19:19:49 alec Exp $
  */
 
-$layout['pagetitle'] = "Podgld bazy danych";
+$layout['pagetitle'] = 'Podgld bazy danych';
 
 $database = $LMS->DatabaseFetchContent($_GET['db']);
 
@@ -33,11 +33,12 @@ if($_GET['rawmode']=="true")
 	$database['rawmode'] = TRUE;
 	if($_GET['save']=="true")
 	{
-		header("Content-Type: application/octetstream");
-		header("Content-Disposition: attachment; filename=lms-backup-".date("Ymd-His",$_GET['db']).".sql");
+		header('Content-Type: application/octetstream');
+		header('Content-Disposition: attachment; filename=lms-backup-'.date("Ymd-His",$_GET['db']).'.sql');
+		header('Pragma: public');
 	}
 	else
-		header("Content-Type: text/plain; charset=ISO-8859-2");
+		header('Content-Type: text/plain; charset=ISO-8859-2');
 }
 
 $SMARTY->assign('database',$database);
