@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: genfake.php,v 1.17 2004/06/22 19:34:44 alec Exp $
+ *  $Id: genfake.php,v 1.22.2.3 2005/01/13 08:46:16 alec Exp $
  */
 
 // Nazwiska
@@ -1531,7 +1531,7 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 	$LMS->NetworkAdd($netdata);
 
 	echo '<B>Generuje uytkownikw...</B><BR>';	
-	$startip = ip_long('192.168.0.0');
+	$startip = ip_long('192.168.0.0')+1;
 	$cnt = 0;
 	$lnsize = sizeof($lastnames);
 	$nsize = sizeof($names);
@@ -1558,8 +1558,10 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 		$useradd['phone3'] = '';
 		$useradd['nip'] = '';
 		$useradd['pesel'] = '';
+		$useradd['serviceaddr'] = '';
 		$useradd['info'] = '';
 		$useradd['message'] = '';
+		$useradd['pin'] = rand(10000,99999);
 		$id = $LMS->UserAdd($useradd);
 		$LMS->AddAssignMent(array( 'tariffid' => $useradd['tariff'], 'userid' => $id, 'period' => 1, 'at' => $useradd['payday'], 'invoice' => 0, 'datefrom' => 0, 'dateto' => 0));
 		$nodes = mt_rand(1,3);
@@ -1573,7 +1575,8 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 			$nodedata['ownerid'] = $id;
 			$nodedata['access'] = 1;
 			$nodedata['warning'] = 0;
-			$LMS->NodeAdd($nodedata);
+			if($nodeid = $LMS->NodeAdd($nodedata))
+				$DB->Execute('UPDATE nodes SET lastonline=? WHERE id=? ', array(mt_rand(time()-2592000,time()+2592000),$nodeid));
 		}
 		$startip ++;
 	}
@@ -1588,7 +1591,7 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 		$prod = mt_rand(0,$sprod-1);
 		$LMS->NetDevAdd(array(
 			'name' => "SWITCH_".$i,
-			'location' => "",
+			'location' => $streets[mt_rand(0,$ssize-1)].' '.mt_rand(1,50),
 			'description' => "",
 			'producer' => $producer[$prod],
 			'model' => "10/100 Mbps Switch",
