@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice.php,v 1.24 2004/04/01 18:14:24 lukasz Exp $
+ *  $Id: invoice.php,v 1.25.2.2 2005/01/01 19:19:51 alec Exp $
  */
 header('Content-Type: '.$LMS->CONFIG['invoices']['content_type']);
 if($LMS->CONFIG['invoices']['attachment_name'] != '')
@@ -40,10 +40,10 @@ if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
 	{
 		echo '<PRE>';
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
+		$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
 		foreach(split('\+', $which) as $type)
 		{
 			$SMARTY->assign('type',$type);
-
 			$SMARTY->assign('invoice',$invoice);
 			$SMARTY->display($LMS->CONFIG['invoices']['template_file']);
 		}
@@ -59,6 +59,7 @@ elseif($_GET['fetchsingle'])
 	$ntempl = str_replace('%Y',$invoice['year'],$ntempl);
 	$layout['pagetitle'] = 'Faktura VAT nr '.$ntempl;
 	$invoice['last'] = TRUE;
+	$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
 	$SMARTY->assign('invoice',$invoice);
 	$SMARTY->display('clearheader.html');
 	$SMARTY->assign('type','ORYGINA');
@@ -72,6 +73,7 @@ elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 	$ntempl = str_replace('%M',$invoice['month'],$ntempl);
 	$ntempl = str_replace('%Y',$invoice['year'],$ntempl);
 	$layout['pagetitle'] = 'Faktura VAT nr '.$ntempl;	
+	$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
 	$SMARTY->assign('invoice',$invoice);
 	$SMARTY->display('clearheader.html');
 	$SMARTY->assign('type','ORYGINA');
