@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.13 2004/04/13 09:01:52 chilek Exp $
+ *  $Id: invoicelist.php,v 1.13.2.3 2005/01/01 19:19:51 alec Exp $
  */
 
 $layout['pagetitle'] = 'Lista faktur';
@@ -55,7 +55,6 @@ $SMARTY->assign('page',$page);
 $SMARTY->assign('marks',$marks);
 $SMARTY->assign('marked',$marked);
 $SMARTY->assign('invoicelist',$invoicelist);
-$SMARTY->assign('openonload',$_GET['openonload']);
 $SMARTY->display('invoicelist.html');
 
 ?>
