@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenew.php,v 1.12 2004/05/31 06:50:31 alec Exp $
+ *  $Id: invoicenew.php,v 1.12.2.3 2005/01/01 19:19:54 alec Exp $
  */
 
 $layout['pagetitle'] = 'Nowa faktura';
@@ -88,7 +88,7 @@ switch($_GET['action'])
 		unset($_SESSION['invoicecontents']);
 		unset($_SESSION['invoicecustomer']);
 		unset($_SESSION['invoice']);
-		header('Location: ?m=invoicelist&openonload='.$iid);
+		header('Location: ?m=invoice&id='.$iid);
 		die;
 	break;
 }
