@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,12 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailing.php,v 1.21 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: mailing.php,v 1.25.2.2 2005/01/01 19:19:55 alec Exp $
  */
 
 $layout['pagetitle'] = "Mailing";
 
-$SMARTY->assign('layout',$layout);
+$SMARTY->assign('networks', $LMS->GetNetworks());
+$SMARTY->assign('usergroups', $LMS->UsergroupGetAll());
+$SMARTY->assign('admininfo', $LMS->GetAdminInfo($SESSION->id));
 $SMARTY->display('mailing.html');
 
 ?>
