@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,23 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.18 2004/05/28 07:12:36 alec Exp $
+ *  $Id: netdevmap.php,v 1.29.2.4 2005/01/01 19:19:57 alec Exp $
+ */
 
-                                 _
- _   ___      ____ _  __ _  __ _| |
-| | | \ \ /\ / / _` |/ _` |/ _` | |
-| |_| |\ V  V / (_| | (_| | (_| |_|
- \__,_| \_/\_/ \__,_|\__, |\__,_(_)
-                     |___/
-
-jak macie wasne pomysy, to nie modyfikujcie tego pliku a zrbcie tymczasowy
-nowy.
-
-*/
+function drawtext($image, $font, $x, $y, $text, $color, $bgcolor)
+{
+	imagestring($image, $font, $x + 1, $y + 1, $text, $bgcolor);
+	imagestring($image, $font, $x + 1, $y - 1, $text, $bgcolor);
+	imagestring($image, $font, $x - 1, $y + 1, $text, $bgcolor);
+	imagestring($image, $font, $x - 1, $y - 1, $text, $bgcolor);
+	imagestring($image, $font, $x, $y, $text, $color);
+}
 
 function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 {
-//	$fields[] = array( 'x' => -1, 'y' => 1 );
 	$fields[] = array( 'x' => 0, 'y' => 5 );
 	$fields[] = array( 'x' => 5, 'y' => 5 );     
 	$fields[] = array( 'x' => 5, 'y' => 0 );
@@ -46,6 +43,22 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 	$fields[] = array( 'x' => -5, 'y' => -5 );
 	$fields[] = array( 'x' => -5, 'y' => 0 );
 	$fields[] = array( 'x' => -5, 'y' => 5 );
+	$fields[] = array( 'x' => 5, 'y' => 10 );
+	$fields[] = array( 'x' => 5, 'y' => -10 );
+	$fields[] = array( 'x' => -5, 'y' => 10 );
+	$fields[] = array( 'x' => -5, 'y' => -10 );
+	$fields[] = array( 'x' => 10, 'y' => 5 );
+	$fields[] = array( 'x' => 10, 'y' => -5 );
+	$fields[] = array( 'x' => -10, 'y' => 5 );
+	$fields[] = array( 'x' => -10, 'y' => -5 );
+	$fields[] = array( 'x' => 5, 'y' => 15 );
+	$fields[] = array( 'x' => 5, 'y' => -15 );
+	$fields[] = array( 'x' => -5, 'y' => 15 );
+	$fields[] = array( 'x' => -5, 'y' => -15 );
+	$fields[] = array( 'x' => 10, 'y' => 15 );
+	$fields[] = array( 'x' => 10, 'y' => -15 );
+	$fields[] = array( 'x' => -10, 'y' => 15 );
+	$fields[] = array( 'x' => -10, 'y' => -15 );
 
 	unset($nodefields);
 
@@ -76,8 +89,8 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 	
 	if($device == 0)
 	{
-		$device = $DB->GetOne('SELECT id FROM netdevices ORDER BY id ASC');
-		makemap($DB, $map, $seen, $device, $x, $y);
+		if($device = $DB->GetOne('SELECT id FROM netdevices ORDER BY id ASC'))
+			makemap($DB, $map, $seen, $device, $x, $y);
 	}
 	else
 	{
@@ -134,16 +147,81 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 
 $layout['pagetitle'] = "Mapa pocze sieciowych";
 
+$start = sprintf('%d',$_GET['start']);
+	
 if($_GET['graph'] == "")
 {
-	$SMARTY->assign('deviceslist',$DB->GetAll('SELECT id, name FROM netdevices ORDER BY name ASC'));
+	makemap($DB,$map,$seen,$start);
+	
+	if($map)
+	{
+	foreach($map as $idx => $x)
+	{
+		if($minx == NULL)
+			$minx = $idx;
+		elseif($idx < $minx)
+			$minx = $idx;
+		
+		if($idx > $maxx)
+			$maxx = $idx;
+		foreach($x as $idy => $y)
+		{
+			if($miny == NULL)
+				$miny = $idy;
+			elseif($idy < $miny)
+				$miny = $idy;
+
+			if($idy > $maxy)
+				$maxy = $idy;
+		}
+	}
+
+	$widthx = $maxx - $minx;
+	$widthy = $maxy - $miny;
+	$cellw = 70;
+	$cellh = 30;
+	$celltmargin = 20;
+	$celllmargin = 10;
+	$imgwx = $cellw * ($widthx + 2);
+	$imgwy = $cellh * ($widthy + 2);
+
+	foreach($map as $idx => $x)
+	{
+		foreach($x as $idy => $device)
+		{
+			$celx = $idx - $minx;
+			$cely = $idy - $miny;
+			if(eregi('^n',$device))
+			{
+				$device = str_replace('n','',$device);
+				list($nodeid,$device) = explode('.',$device);
+				$nodemap[$nodeid]['x'] = (($celx * ($cellw)) + $celllmargin) +4;
+				$nodemap[$nodeid]['y'] = (($cely * ($cellh)) + $celltmargin) +4;
+				$nodemap[$nodeid]['id'] = $nodeid;
+			}
+			else
+			{
+				$devicemap[$device]['x'] = (($celx * ($cellw)) + $celllmargin) +4;
+				$devicemap[$device]['y'] = (($cely * ($cellh)) + $celltmargin) +4;
+				$devicemap[$device]['id'] = $device;
+			}
+		}
+	}
+	if(sizeof($nodemap)) sort($nodemap);
+	sort($devicemap);
+	}
+	
+	$deviceslist = $DB->GetAll('SELECT id, name FROM netdevices ORDER BY name ASC');
+	$SMARTY->assign('devicemap',$devicemap);
+	$SMARTY->assign('nodemap',$nodemap);
+	$SMARTY->assign('deviceslist',$deviceslist);
+	$SMARTY->assign('emptydb', sizeof($deviceslist) ? FALSE : TRUE);
 	$SMARTY->assign('gderror', ! function_exists('imagepng'));
 	$SMARTY->assign('start',$_GET['start']);
 	$SMARTY->display('netdevmap.html');
-}
+} 
 else
 {	
-	$start = sprintf('%d',$_GET['start']);
 	makemap($DB,$map,$seen,$start);
 	foreach($map as $idx => $x)
 	{
@@ -171,7 +249,7 @@ else
 	$widthy = $maxy - $miny;
 	$cellw = 70;
 	$cellh = 30;
-	$celltmargin = 10;
+	$celltmargin = 20;
 	$celllmargin = 10;
 	$imgwx = $cellw * ($widthx + 2);
 	$imgwy = $cellh * ($widthy + 2);
@@ -224,7 +302,7 @@ else
 		imageline($im, $src_px+9, $src_py+9, $dst_px+9, $dst_py+9, $green);
 	}
 
-	foreach($nodemap as $node)
+	if($nodemap) foreach($nodemap as $node)
 	{
 		$src_celx = $node['x'];
 		$src_cely = $node['y'];
@@ -237,25 +315,31 @@ else
 		imageline($im, $src_px+4, $src_py+4, $dst_px+4, $dst_py+4, $red);
 	}
 
-	$im_nd = imagecreatefrompng('img/netdev.png');
-	$im_n = imagecreatefrompng('img/node.png');
+	$im_n_unk = imagecreatefrompng('img/node_unk.png');
+	$im_n_off = imagecreatefrompng('img/node_off.png');
+	$im_n_on = imagecreatefrompng('img/node_on.png');
+	$im_d_unk = imagecreatefrompng('img/netdev_unk.png');
+	$im_d_off = imagecreatefrompng('img/netdev_off.png');
+	$im_d_on = imagecreatefrompng('img/netdev_on.png');
 
-//	print_r($nodemap);
-	
-	foreach($nodemap as $nodeid => $node)
+	if($nodemap) foreach($nodemap as $nodeid => $node)
 	{
 		$celx = $node['x'];
 		$cely = $node['y'];
 		$px = (($celx * ($cellw)) + $celllmargin);
 		$py = (($cely * ($cellh)) + $celltmargin);
-		imagecopy($im,$im_n,$px,$py,0,0,15,16);
-		$nodedata = $DB->GetRow('SELECT name, INET_NTOA(ipaddr) AS ip FROM nodes WHERE id=?',array($nodeid));
-//		imagestring($im, 1, $px + 15, $py - 8, $nodeid.' ('.$celx.','.$cely.')', $blue);
-		imagestring($im, 1, $px + 15, $py - 8, $nodedata['ip'], $blue);
-		imagestring($im, 1, $px + 15, $py + 2, $nodedata['name'], $black);
-	}
-				
+		$nodedata = $DB->GetRow('SELECT name, INET_NTOA(ipaddr) AS ip, lastonline FROM nodes WHERE id=?',array($nodeid));
+		if ($nodedata['lastonline']) {	
+			if ((time()-$nodedata['lastonline'])>$LMS->CONFIG['phpui']['lastonline_limit'])
+				imagecopy($im,$im_n_off,$px,$py,0,0,15,16);
+			else 
+				imagecopy($im,$im_n_on,$px,$py,0,0,15,16);
+		} else 
+			imagecopy($im,$im_n_unk,$px,$py,0,0,15,16);
 		
+		drawtext($im, 1, $px + 15, $py - 8, $nodedata['ip'], $blue, $lightbrown);
+		drawtext($im, 1, $px + 15, $py + 2, $nodedata['name'], $black, $lightbrown);
+	}
 
 	foreach($devicemap as $deviceid => $device)
 	{
@@ -263,16 +347,25 @@ else
 		$cely = $device['y'];
 		$px = (($celx * ($cellw)) + $celllmargin);
 		$py = (($cely * ($cellh)) + $celltmargin);
-		imagecopy($im,$im_nd,$px,$py,0,0,16,16);
-//		imagestring($im, 1, $px + 20, $py - 8, $deviceid.' ('.$celx.','.$cely.')', $blue);
-		$deviceip = $DB->GetCol('SELECT INET_NTOA(ipaddr) FROM nodes WHERE ownerid=0 AND netdev=? ORDER BY ipaddr', array($deviceid));
-		if($deviceip[0]) imagestring($im, 1, $px + 20, $py - ($deviceip[1]?17:8), $deviceip[0], $blue);
-		if($deviceip[1]) imagestring($im, 1, $px + 20, $py - 8, $deviceip[1], $blue);
-		if($deviceip[2]) imagestring($im, 1, $px + 20, $py + 17, $deviceip[2], $blue);
-		if($deviceip[3]) imagestring($im, 1, $px + 20, $py + 26, $deviceip[3], $blue);
-		imagestring($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $darkred);
+		
+		$lastonline = $DB->GetOne('SELECT MAX(lastonline) FROM nodes WHERE ownerid=0 AND netdev=?', array($deviceid));
+		if ($lastonline) {	
+			if ((time()-$lastonline)>$LMS->CONFIG['phpui']['lastonline_limit'])
+				imagecopy($im,$im_d_off,$px,$py,0,0,16,16);
+			else 
+				imagecopy($im,$im_d_on,$px,$py,0,0,16,16);
+		} else 
+			imagecopy($im,$im_d_unk,$px,$py,0,0,16,16);
+		
+		$devip = $DB->GetCol('SELECT INET_NTOA(ipaddr) FROM nodes WHERE ownerid=0 AND netdev=? ORDER BY ipaddr LIMIT 4', array($deviceid));
+		if($devip[0]) drawtext($im, 1, $px + 20, $py - ($devip[1]?17:8), $devip[0], $blue, $lightbrown);
+		if($devip[1]) drawtext($im, 1, $px + 20, $py - 8, $devip[1], $blue, $lightbrown);
+		if($devip[2]) drawtext($im, 1, $px + 20, $py + 17, $devip[2], $blue, $lightbrown);
+		if($devip[3]) drawtext($im, 1, $px + 20, $py + 26, $devip[3], $blue, $lightbrown);
+		
+		drawtext($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $black, $lightbrown);
+		drawtext($im, 2, $px + 20, $py + 18, $DB->GetOne('SELECT location FROM netdevices WHERE id=?',array($deviceid)), $green, $lightbrown);
 	}
-	
 		
 	imagepng($im);
 }
