@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netinfo.php,v 1.27 2004/03/11 17:24:22 lukasz Exp $
+ *  $Id: netinfo.php,v 1.27.2.3 2005/01/01 19:19:59 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
@@ -35,7 +35,7 @@ if (isset($_SESSION['ntlp'][$_GET['id']]) && !isset($_GET['page']))
 
 $_SESSION['ntlp'][$_GET['id']] = $_GET['page'];
 
-$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'],1024);
+$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'], $LMS->CONFIG['phpui']['networkhosts_pagelimit']);
 
 $layout['pagetitle'] = "Informacja o sieci: ".$network['name'];
 
