@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeadd.php,v 1.47 2004/07/16 13:03:41 alec Exp $
+ *  $Id: nodeadd.php,v 1.47.2.5 2005/03/10 07:30:49 alec Exp $
  */
 
 
@@ -63,6 +63,8 @@ if(isset($nodedata))
 		$error['ipaddr'] = 'Podany adres IP nie naley do adnej sieci!';
 	elseif(!$LMS->IsIPFree($nodedata['ipaddr']))
 		$error['ipaddr'] = 'Podany adres IP jest zajty!';
+	elseif($LMS->IsIPGateway($nodedata['ipaddr']))
+		$error['ipaddr'] = 'Podany adres IP jest adresem bramy!';
 
 	if(!$nodedata['mac'])
 		$error['mac'] = 'Prosz podac adres MAC!';
@@ -119,12 +121,20 @@ if(isset($_GET['prename']) && $nodedata['name']=='')
 $layout['pagetitle'] = 'Nowy komputer';
 
 $tariffs = $LMS->GetTariffs();
-$balancelist = $LMS->GetUserBalanceList($nodedata['ownerid']);
-$assignments = $LMS->GetUserAssignments($nodedata['ownerid']);
 $users = $LMS->GetUserNames();
 
-$SMARTY->assign('balancelist',$balancelist);
-$SMARTY->assign('assignments',$assignments);
+if($nodedata['ownerid'])
+{
+	$balancelist = $LMS->GetUserBalanceList($nodedata['ownerid']);
+	$assignments = $LMS->GetUserAssignments($nodedata['ownerid']);
+	$usergroups = $LMS->UsergroupGetForUser($nodedata['ownerid']);
+	$otherusergroups = $LMS->GetGroupNamesWithoutUser($nodedata['ownerid']);
+	$SMARTY->assign('balancelist',$balancelist);
+	$SMARTY->assign('assignments',$assignments);
+	$SMARTY->assign('usergroups',$usergroups);
+	$SMARTY->assign('otherusergroups',$otherusergroups);
+}
+
 $SMARTY->assign('tariffs',$tariffs);
 $SMARTY->assign('users',$users);
 $SMARTY->assign('error',$error);
