@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.54 2004/07/21 19:59:09 alec Exp $
+ *  $Id: nodeedit.php,v 1.54.2.6 2005/01/13 08:42:26 alec Exp $
  */
 
 if(!$LMS->NodeExists($_GET['id']))
@@ -80,8 +80,11 @@ if(isset($nodeedit))
 	{
 		if($LMS->IsIPValid($nodeedit['ipaddr'])) 
 		{
-			if(!$LMS->IsIPFree($nodeedit['ipaddr']) && $LMS->GetNodeIPByID($nodeedit['id'])!=$nodeedit['ipaddr'])
+			$ip = $LMS->GetNodeIPByID($nodeedit['id']);
+			if($ip!=$nodeedit['ipaddr'] && !$LMS->IsIPFree($nodeedit['ipaddr']))
 				$error['ipaddr'] = 'Podany adres IP jest zajty!';
+			elseif($ip!=$nodeedit['ipaddr'] && $LMS->IsIPGateway($nodeedit['ipaddr']))
+				$error['ipaddr'] = 'Podany adres IP jest adresem bramy!';
 		}
 		else
 			$error['ipaddr'] = 'Podany adres IP nie naley do adnej sieci!';
@@ -100,7 +103,7 @@ if(isset($nodeedit))
 
 	if($nodeedit['name']=='')
 		$error['name'] = 'Podaj nazw!';
-	elseif($LMS->GetNodeIDByName($nodeedit['name']) && $LMS->GetNodeIDByNAME($nodeedit['name']) != $nodeedit['id'])
+	elseif($LMS->GetNodeIDByName($nodeedit['name']) && $LMS->GetNodeIDByName($nodeedit['name']) != $nodeedit['id'])
 		$error['name'] = 'Ta nazwa jest zajta!';
 	elseif(!eregi("^[_a-z0-9-]+$",$nodeedit['name']))
 		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
@@ -109,8 +112,8 @@ if(isset($nodeedit))
 
 	if($nodeedit['access']!=1)
 		$nodeedit['access'] = 0;
-        if($nodeedit[warning]!=1)
-                $nodeedit[warning] = 0;	
+        if($nodeedit['warning'] != 1)
+                $nodeedit['warning'] = 0;	
 
 	if($nodeinfo['netdev'] != $nodeedit['netdev'] && $nodeedit['netdev'] != 0)
 	{
@@ -122,7 +125,7 @@ if(isset($nodeedit))
 	
 	$nodeinfo['name'] = $nodeedit['name'];
 	$nodeinfo['mac'] = $nodeedit['mac'];
-	$nodeinfo['ipaddr'] = $nodeedit['ipaddr'];
+	$nodeinfo['ip'] = $nodeedit['ipaddr'];
 	$nodeinfo['access'] = $nodeedit['access'];
 	$nodeinfo['ownerid'] = $nodeedit['ownerid'];
 
