@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeinfo.php,v 1.31 2004/03/11 17:24:22 lukasz Exp $
+ *  $Id: nodeinfo.php,v 1.33.2.2 2005/01/01 19:20:01 alec Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
@@ -47,6 +47,13 @@ elseif($LMS->GetNodeOwner($_GET['id']) == 0)
 	die;
 }
 
+if($_GET['devid'])
+{
+	$error['netdev'] = 'Brak wolnych portw w wybranym urzdzeniu!';
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('netdevice', $_GET['devid']);
+}
+
 $nodeid = $_GET['id'];
 $ownerid = $LMS->GetNodeOwner($nodeid);
 $tariffs = $LMS->GetTariffs();
@@ -54,6 +61,8 @@ $userinfo = $LMS->GetUser($ownerid);
 $nodeinfo = $LMS->GetNode($nodeid);
 $balancelist = $LMS->GetUserBalanceList($ownerid);
 $assignments = $LMS->GetUserAssignments($ownerid);
+$usergroups = $LMS->UsergroupGetForUser($ownerid);
+$otherusergroups = $LMS->GetGroupNamesWithoutUser($ownerid);
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
@@ -77,6 +86,8 @@ $SMARTY->assign('balancelist',$balancelist);
 $SMARTY->assign('userinfo',$userinfo);
 $SMARTY->assign('nodeinfo',$nodeinfo);
 $SMARTY->assign('assignments',$assignments);
+$SMARTY->assign('usergroups',$usergroups);
+$SMARTY->assign('otherusergroups',$otherusergroups);
 $SMARTY->assign('tariffs',$tariffs);
 $SMARTY->display('nodeinfo.html');
 
