@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: print.php,v 1.34 2004/04/25 13:25:34 alec Exp $
+ *  $Id: print.php,v 1.34.2.4 2005/01/01 19:20:03 alec Exp $
  */
 
 switch($_GET['type'])
@@ -111,7 +111,7 @@ switch($_GET['type'])
 
 		if($to) {
 			list($year, $month, $day) = split('/',$to);
-			$date['to'] = mktime(0,0,0,$month,$day,$year);
+			$date['to'] = mktime(23,59,59,$month,$day,$year);
 		} else { 
 			$to = date("Y/m/d",time());
 			$date['to'] = mktime(23,59,59); //koniec dnia dzisiejszego
@@ -177,7 +177,7 @@ switch($_GET['type'])
 		
 		if($to) {
 			list($year, $month, $day) = split('/',$to);
-			$date['to'] = mktime(0,0,0,$month,$day,$year);
+			$date['to'] = mktime(23,59,59,$month,$day,$year);
 		} else {
 			$to = date("Y/m/d",time());
 			$date['to'] = mktime(23,59,59); //koniec dnia dzisiejszego
@@ -234,7 +234,7 @@ switch($_GET['type'])
 		
 		if($to) {
 			list($year, $month, $day) = split('/',$to);
-			$date['to'] = mktime(0,0,0,$month,$day,$year);
+			$date['to'] = mktime(23,59,59,$month,$day,$year);
 		} else {
 			$to = date("Y/m/d",time());
 			$date['to'] = mktime(23,59,59); //koniec dnia dzisiejszego
@@ -265,11 +265,8 @@ switch($_GET['type'])
 		
 	default: /*******************************************************/
 		$layout['pagetitle'] = 'Wydruki';
-		$admins = $LMS->GetAdminList();
-		unset($admins['total']);
-		
 		$SMARTY->assign('users', $LMS->GetUserNames());
-		$SMARTY->assign('admins', $admins);
+		$SMARTY->assign('admins', $LMS->GetAdminNames());
 		$SMARTY->assign('networks', $LMS->GetNetworks());
 		$SMARTY->assign('usergroups', $LMS->UsergroupGetAll());
 		$SMARTY->assign('printmenu', $_GET['menu']);
