@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: quicksearch.php,v 1.3 2004/04/02 21:02:38 alec Exp $
+ *  $Id: quicksearch.php,v 1.4.2.4 2005/01/01 19:20:03 alec Exp $
  */
 
 $search = trim($_GET['what']);
@@ -30,7 +30,7 @@ switch($_GET['mode'])
 {
 	case 'user':
 		if(($userid = $DB->GetOne('SELECT id FROM users WHERE id = '.intval($search))) ||
-		   ($userid = $DB->GetOne('SELECT id FROM users WHERE lastname ?LIKE? ? OR address ?LIKE? ? OR phone1 = ? OR phone2 = ? OR phone3 = ? OR email = ? LIMIT 1', array('%'.$search.'%', '%'.$search.'%', $search, $search, $search, $search)))
+		   ($userid = $DB->GetOne('SELECT id FROM users WHERE deleted=0 AND lastname ?LIKE? ? OR address ?LIKE? ? OR phone1 = ? OR phone2 = ? OR phone3 = ? OR email = ? LIMIT 1', array('%'.$search.'%', '%'.$search.'%', $search, $search, $search, $search)))
 		   )
 			$target = '?m=userinfo&id='.$userid;
 		else
@@ -38,13 +38,26 @@ switch($_GET['mode'])
 	break;
 
 	case 'node':
-		if(($nodeid = $DB->GetOne('SELECT id FROM nodes WHERE id = '.ip2long($search))) ||
+		if(($nodeid = $DB->GetOne('SELECT id FROM nodes WHERE id = '.(ip2long($search)!==FALSE ? ip2long($search) : -1))) ||
 		   ($nodeid = $DB->GetOne('SELECT id FROM nodes WHERE ipaddr = ? OR name = UPPER(?) OR mac = UPPER(?) LIMIT 1', array(ip_long($search), $search, $search)))
 		   )
 			$target = '?m=nodeinfo&id='.$nodeid;
 		else
 			$target = '?m=nodelist';
 	break;
+	
+	case 'ticket':
+		if(intval($search))
+			$target = '?m=rtticketview&id='.$search;
+		else
+		{
+			$_SESSION['rtsearch']['username'] = $search;
+			$target = '?m=rtsearch&search=1';
+		}
+	break;
+	
+	
+
 }
 
 if($target == '')
