@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueadd.php,v 1.7 2004/07/12 08:25:52 alec Exp $
+ *  $Id: rtqueueadd.php,v 1.7.2.3 2005/01/01 19:20:04 alec Exp $
  */
 
 $queue = $_POST['queue'];
@@ -55,8 +55,7 @@ if(isset($queue))
 	}
 }
 
-$admins = $LMS->GetAdminList();
-unset($admins['total']);
+$admins = $LMS->GetAdminNames();
 
 foreach($admins as $admin) 
 {
