@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketedit.php,v 1.4 2004/07/11 20:55:50 alec Exp $
+ *  $Id: rtticketedit.php,v 1.4.2.3 2005/01/01 19:20:06 alec Exp $
  */
 
 $ticketedit = $_POST['ticket'];
@@ -73,16 +73,13 @@ if(isset($ticketedit))
 	$ticket['owner'] = $ticketedit['owner'];
 }
 
-$adminlist = $LMS->GetAdminList();
-unset($adminlist['total']);	
-
 $layout['pagetitle'] = 'Edycja zgoszenia Nr '.sprintf("%06d",$ticket['ticketid']);
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
 $SMARTY->assign('ticket', $ticket);
 $SMARTY->assign('queuelist', $LMS->GetQueueNames());
-$SMARTY->assign('adminlist', $adminlist);
+$SMARTY->assign('adminlist', $LMS->GetAdminNames());
 $SMARTY->assign('error', $error);
 $SMARTY->display('rtticketedit.html');
 
