@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,23 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tarifflist.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: tarifflist.php,v 1.24.2.2 2005/01/01 19:20:06 alec Exp $
  */
 
-$layout[pagetitle]="Lista taryf";
+$layout['pagetitle'] = "Lista taryf";
 
 $tarifflist = $LMS->GetTariffList();
 
-$listdata[total] = $tarifflist[total];
-$listdata[totalincome] = $tarifflist[totalincome];
-$listdata[totalusers] = $tarifflist[totalusers];
-$listdata[totalcount] = $tarifflist[totalcount];
+$listdata['total'] = $tarifflist['total'];
+$listdata['totalincome'] = $tarifflist['totalincome'];
+$listdata['totalusers'] = $tarifflist['totalusers'];
+$listdata['totalcount'] = $tarifflist['totalcount'];
+$listdata['totalassignmentcount'] = $tarifflist['totalassignmentcount'];
 
-unset($tarifflist[total],$tarifflist[totalincome],$tarifflist[totalusers],$tarifflist[totalcount]);
+unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalusers'],$tarifflist['totalcount'],$tarifflist['totalassignmentcount']);
 
-$SMARTY->assign("tarifflist",$tarifflist);
-$SMARTY->assign("listdata",$listdata);
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("tarifflist.html");
+$SMARTY->assign('tarifflist',$tarifflist);
+$SMARTY->assign('listdata',$listdata);
+$SMARTY->display('tarifflist.html');
 
 ?>
