@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useradd.php,v 1.47 2004/03/11 21:06:50 alec Exp $
+ *  $Id: useradd.php,v 1.50.2.4 2005/01/01 19:20:08 alec Exp $
  */
 
 $useradd = $_POST['useradd'];
@@ -37,14 +37,13 @@ if($useradd['name']=='' && $useradd['lastname']=='' && $useradd[phone1]=='' && $
 }
 elseif(isset($useradd))
 {
-
 	if($useradd['lastname']=='')
 		$error['username']='Pola \'nazwisko/nazwa\' oraz \'imi\' nie mog by puste!';
 	
 	if($useradd['address']=='')
 		$error['address']='Prosz poda adres!';
 	
-	if($useradd['nip'] !='' && !eregi('^[0-9]{3}-[0-9]{3}-[0-9]{2}-[0-9]{2}$',$useradd['nip']) && !eregi('^[0-9]{3}-[0-9]{2}-[0-9]{2}-[0-9]{3}$',$useradd['nip']))
+	if($useradd['nip'] !='' && !check_nip($useradd['nip']))
 		$error['nip'] = 'Podany NIP jest bdny!';
 
 	if($useradd['pesel'] != '' && !check_pesel($useradd['pesel']))
@@ -53,11 +52,20 @@ elseif(isset($useradd))
 	if($useradd['zip'] !='' && !eregi('^[0-9]{2}-[0-9]{3}$',$useradd['zip']))
 		$error['zip'] = 'Podany kod pocztowy jest bdny!';
 
+	if($useradd['email']!='' && !check_email($useradd['email']))
+		$error['email'] = 'Podany email nie wydaje si by poprawny!';
+
 	if($useradd['gguin'] == '')
 		$useradd['gguin'] = 0;
+	
+	if($useradd['pin'] == '')
+		$useradd['pin'] = 0;
 
 	if($useradd['gguin'] !=0 && !eregi('^[0-9]{4,}$',$useradd['gguin']))
 		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
+
+        if($useradd['pin']!=0 && !eregi('^[0-9]{4,6}$',$useradd['pin']))
+	        $error['pin'] = 'Podany numer PIN jest niepoprawny!';
 	
 	if(!$error)
 	{
