@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,9 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userbalance.php,v 1.25 2004/03/11 17:24:22 lukasz Exp $
+ *  $Id: userbalance.php,v 1.26.2.2 2005/01/01 19:20:09 alec Exp $
  */
 
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+
 if(!$LMS->UserExists($_GET['id']))
 	header("Location: ?m=userlist");
 
