@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useredit.php,v 1.63 2004/07/14 13:28:04 alec Exp $
+ *  $Id: useredit.php,v 1.66.2.4 2005/01/01 19:20:10 alec Exp $
  */
 
 $userdata = $_POST['userdata'];
@@ -60,7 +60,7 @@ elseif(isset($userdata))
 	if($userdata['address']=='')
 		$error['address'] = 'Prosz poda adres!';
 
-	if($userdata['nip'] !='' && !eregi('^[0-9]{3}-[0-9]{3}-[0-9]{2}-[0-9]{2}$',$userdata['nip']) && !eregi('^[0-9]{3}-[0-9]{2}-[0-9]{2}-[0-9]{3}$',$userdata['nip']) && !check_nip($userdata['nip']))
+	if($userdata['nip'] !='' && !check_nip($userdata['nip']))
 		$error['nip'] = 'Podany NIP jest bdny!';
 
 	if(!check_pesel($userdata['pesel']) && $userdata['pesel'] != '')
@@ -69,12 +69,21 @@ elseif(isset($userdata))
 	if($userdata['zip'] !='' && !eregi('^[0-9]{2}-[0-9]{3}$',$userdata['zip']))
 		$error['zip'] = 'Podany kod pocztowy jest bdny!';
 
+	if($userdata['email']!='' && !check_email($userdata['email']))
+		$error['email'] = 'Podany email nie wydaje si by poprawny!';
+
 	if($userdata['gguin'] == '')
 		$userdata['gguin'] = 0;
 
+	if($userdata['pin'] == '')
+		$userdata['pin'] = 0;
+
 	if($userdata['gguin']!=0 && !eregi('^[0-9]{4,}$',$userdata['gguin']))
 		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
 
+	if($userdata['pin']!=0 && !eregi('^[0-9]{4,6}$',$userdata['pin']))
+		$error['pin'] = 'Podany numer PIN jest niepoprawny!';
+
 	if($userdata['status']!=3&&$LMS->GetUserNodesNo($userdata['id'])) 
 		$error['status'] = 'Tylko podczony uytkownik moe posiada komputery!';
 		
