@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergroupadd.php,v 1.3 2004/04/22 19:59:58 alec Exp $
+ *  $Id: usergroupadd.php,v 1.5.2.2 2005/01/01 19:20:12 alec Exp $
  */
 
 $usergroupadd = $_POST['usergroupadd'];
@@ -42,8 +42,8 @@ if(isset($usergroupadd))
 	elseif(strlen($usergroupadd['name']) > 16)
 		$error['name'] = 'Podana nazwa jest za duga!';
 	elseif($LMS->UsergroupGetId($usergroupadd['name']))
-		$error['name'] = 'Istnieje ju grupa o nazwie'.$usergroupadd['name'];
-	elseif(!eregi("^[_a-z0-9-]+$",$usergroupadd['name']))
+		$error['name'] = 'Istnieje ju grupa o nazwie '.$usergroupadd['name'];
+	elseif(!eregi("^[._a-z0-9-]+$",$usergroupadd['name']))
 		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
 
 	if(!$error){
