@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergroupedit.php,v 1.5 2004/04/22 19:59:58 alec Exp $
+ *  $Id: usergroupedit.php,v 1.7.2.3 2005/01/01 19:20:12 alec Exp $
  */
 
 $userassignments = $_POST['userassignments'];
@@ -61,41 +61,44 @@ if(!$LMS->UsergroupExists($_GET['id']))
 	die;
 }
 
-$usergroup = $_POST['usergroup'];
+$usergroup = $LMS->UsergroupGet($_GET['id']);
+$users = $LMS->GetUserWithoutGroupNames($usergroup['id']);
 
-if(isset($usergroup))
+$layout['pagetitle'] = 'Edycja grupy: '.$usergroup['name'];	
+
+$usergroupedit = $_POST['usergroup'];
+
+if(isset($usergroupedit))
 {
-	foreach($usergroup as $key => $value)
-		$usergroup[$key] = trim($value);
+	foreach($usergroupedit as $key => $value)
+		$usergroupedit[$key] = trim($value);
 
-	if($usergroup['name'] == '')
+	$usergroupedit['id'] = $_GET['id'];
+	
+	if($usergroupedit['name'] == '')
 		$error['name'] = 'Musisz poda nazw grupy!';
-	elseif(strlen($usergroup['name']) > 16)
+	elseif(strlen($usergroupedit['name']) > 16)
 		$error['name'] = 'Podana nazwa jest za duga!';
-	elseif($LMS->UsergroupGetId($usergroup['name']) && $LMS->UsergroupGetName($usergroup['id'] != $usergroup['name']))
-		$error['name'] = 'Istnieje ju grupa o nazwie'.$usergroup['name'];
-	elseif(!eregi("^[_a-z0-9-]+$",$usergroup['name']))
+	elseif( ($id = $LMS->UsergroupGetId($usergroupedit['name'])) && $id != $usergroupedit['id'])
+		$error['name'] = 'Istnieje ju grupa o nazwie '.$usergroupedit['name'];
+	elseif(!eregi("^[._a-z0-9-]+$",$usergroupedit['name']))
 		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
 
-	$usergroup['id'] = $_GET['id'];
-
 	if(!$error)
 	{
-		$LMS->UsergroupUpdate($usergroup);
+		$LMS->UsergroupUpdate($usergroupedit);
 		header('Location: ?m=usergroupinfo&id='.$usergroup['id']);
 		die;
 	}
+
+	$usergroup['description'] = $usergroupedit['description'];
+	$usergroup['name'] = $usergroupedit['name'];
 }
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$layout['pagetitle'] = 'Edycja grupy: '.$usergroup['name'];	
-
-$usergroup = $LMS->UsergroupGet($_GET['id']);
-$users = $LMS->GetUserWithoutGroupNames($_GET['id']);
-
 $SMARTY->assign('usergroup',$usergroup);
-$SMARTY->assign('error',$error);
+$SMARTY->assign('error', $error);
 $SMARTY->assign('users', $users);
 $SMARTY->assign('userscount', sizeof($users));
 $SMARTY->display('usergroupedit.html');
