@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.4.5 Persus
  *
- *  (C) Copyright 2001-2004 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.37 2004/07/05 23:27:54 lukasz Exp $
+ *  $Id: welcome.php,v 1.37.2.3 2005/01/01 19:20:15 alec Exp $
  */
 
 require_once($_LIB_DIR.'/Sysinfo.class.php');
@@ -34,6 +34,7 @@ $layout['pagetitle'] = 'LAN Management System';
 $layout['dbversion'] = $LMS->DB->GetDBVersion();
 $layout['dbtype'] = $LMS->CONFIG['database']['type'];
 
+$SMARTY->assign('rtstats', $LMS->RTStats());
 $SMARTY->assign('sysinfo',$SI->get_sysinfo());
 $SMARTY->assign('userstats',$LMS->UserStats());
 $SMARTY->assign('nodestats',$LMS->NodeStats());
